#
# spec file for package python-inflect
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-inflect
Version:        7.3.1
Release:        1.1
Summary:        Methods for working on numbers and nouns
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jaraco/inflect
Source0:        https://files.pythonhosted.org/packages/source/i/inflect/inflect-%{version}.tar.gz
# PATCH-FIX-UPSTREAM typing_extensions-version.patch bsc#[0-9]+ mcepl@suse.com
# Correct handling of the potential missing Annotated type
Patch0:         typing_extensions-version.patch
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module more-itertools >= 8.5.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module typeguard}
BuildRequires:  %{python_module typing_extensions if %python-base < 3.9}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{python_module typeguard}
Requires:       python-more-itertools >= 8.5.0
BuildArch:      noarch
%python_subpackages

%description
Correctly generate plurals, singular nouns, ordinals, indefinite articles; convert numbers to words.

%prep
%setup -q -n inflect-%{version}
# sed -i 's/addopts=--doctest-modules --flake8 --black --cov/addopts=--doctest-modules/g' pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/

%files %{python_files}
%license LICENSE
%doc NEWS.rst README.rst
%{python_sitelib}/inflect
%{python_sitelib}/inflect-%{version}*-info

%changelog
* Sat Sep  7 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
- Add typing_extensions-version.patch cleaning up problematic
  handling with Annotated type on different versions of Pythons.
* Wed Sep  4 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- update to 7.3.1:
  * Set minimum version of more-itertools to 8.5 (#215)
- version 7.3.0:
  * Restricted typing_extensions to Python 3.8. (#211)
- version 7.2.1:
  * Refactored number_to_words toward reduced complexity.
- version 7.2.0:
  * Replace pydantic with typeguard (#195)
- version 7.1.0:
  * Now handle 'pair of x' in pl_sb_uninflected_complete (#188)
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 7.0.0:
  * Refine type hint for ``singular_noun`` to indicate a literal
    return type for ``False``. (#186)
  * Removed methods renamed in 0.2.0.
  * Project now supports Pydantic 2 while retaining support for
    Pydantic 1. (#187)
  * Added validation of user-defined words and amended the type
    declarations to match, allowing for null values but not empty
    strings. (#187)
  * ``ordinal`` now handles float types correctly without first
    coercing them to strings. (#178)
  * Require Python 3.8 or later.
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.5:
  * Pin to Pydantic 1 to avoid breaking in Pydantic 2.
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.4:
  * Internal cleanup.
  * A/an support now more correctly honors leading
  * capitalized words and abbreviations.
  * Improve support for ordinals for floats.
  * Require pydantic 1.9.1 to avoid ``ValueError``.
  * Minor tweaks and packaging refresh.
  * ``compare`` methods now validate their inputs
    and will raise a more meaningful exception if an
    empty string or None is passed. This expectation is now
    documented.
  * Many public methods now perform validation on arguments.
  * An empty string is no longer allowed for words or text.
  * #15: Fixes to plural edge case handling.
  * Packaging refresh and docs update.
  * #153: Internal refactor to simplify and unify
    ``_plnoun`` and ``_sinoun``.
  * Fixed badges.
  * Rewrite to satisfy type checkers.
  * #147: Enhanced type annotations.
  * Add a ``py.typed`` file so mypy recognizes type
    annotations.
  * Misc fixes in #128, #134, #135, #137, #138, #139, #140, #142,
  * #143, #144.
  * Require Python 3.7 or later.
  * Add support for pluralizing open compound nouns.
  * Modernized the codebase. Added a lot of type
    annotations.
  * Add support for uncountable nouns.
  * Refreshed package metadata.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Mar 15 2022 Stephan Kulow <coolo@suse.com>
- use %%python_expand for %%fdupes
* Wed Jan 20 2021 John Vandenberg <jayvdb@gmail.com>
- Update URL to https://github.com/jaraco/inflect
- Update to v5.0.2
  * Inflect withdraws from Jazzband organisation
    in order to continue to participate in sustained maintenance
    and enterprise support through Tidelift.
    The project continues to honor the guidelines and principles
    behind Jazzband and welcomes contributors openly
- from v5.0.1
  * Identical release validating release process
- from v5.0.0
  * Module no longer exposes a ``__version__`` attribute.
    Instead to query the version installed, use
    importlib.metadata or its backport
- from v4.1.1
  * Refreshed package metadata
* Tue Apr 14 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.1.0
  * Certain operations now allow ignore arbitrary leading words.
  * Require Python 3.6 or later.
  * Drop support for Python 3.4.
  * Project now builds on jaraco/skeleton for shared package management.
* Tue Jun 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 2.1.0
  * Relicensed under the more permissive MIT License.
  * fix inconsistencies with the inflect method
  * Improved unicode handling.
  * Fix capitalization issues in processes where more than one word
    is involved.
  * fix extraneous close parentheses.
  * Dropped support for Python 3.3.
  * Moved hosting to jazzband.
* Tue Jul  4 2017 aloisio@gmx.com
- Converted to singlespec
- Enabled tests
* Tue Aug  2 2016 sor.alexei@meowr.ru
- Switch to Python2.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Feb 14 2015 arun@gmx.de
- initial version
